@@ -65,6 +65,86 @@ class Geocoder(object):
         self.private_key = private_key
         self.proxy = None
 
+    @omnimethod
+    def geocode(self, address, sensor='false', bounds='', region='', language='', components=''):
+        """
+        Given a string address, return a dictionary of information about
+        that location, including its latitude and longitude.
+
+        :param address: Address of location to be geocoded.
+        :type address: string
+        :param sensor: ``'true'`` if the address is coming from, say, a GPS device.
+        :type sensor: string
+        :param bounds: The bounding box of the viewport within which to bias geocode results more prominently.
+        :type bounds: string
+        :param region: The region code, specified as a ccTLD ("top-level domain") two-character value for biasing
+        :type region: string
+        :param components: The components to use when restricting the search results.
+        :type components: string
+        :param language: The language in which to return results.
+        :type language: string
+        :returns: `geocoder return value`_ dictionary
+        :rtype: dict
+        :raises GeocoderError: if there is something wrong with the query.
+
+        For details on the input parameters, visit
+        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingRequests
+
+        For details on the output, visit
+        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingResponses
+
+        """
+
+        params = {
+            'address':  address,
+            'sensor':   sensor,
+            'bounds':   bounds,
+            'region':   region,
+            'language': language,
+            'components': components,
+        }
+
+        if self is not None:
+            return GeocoderResult(self.get_data(params=params))
+        else:
+            return GeocoderResult(Geocoder.get_data(params=params))
+
+    @omnimethod
+    def reverse_geocode(self, lat, lng, sensor='false', bounds='', region='', language=''):
+        """
+        Converts a (latitude, longitude) pair to an address.
+
+        :param lat: latitude
+        :type lat: float
+        :param lng: longitude
+        :type lng: float
+        :return: `Reverse geocoder return value`_ dictionary giving closest
+            address(es) to `(lat, lng)`
+        :rtype: dict
+        :raises GeocoderError: If the coordinates could not be reverse geocoded.
+
+        Keyword arguments and return value are identical to those of :meth:`geocode()`.
+
+        For details on the input parameters, visit
+        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingRequests
+
+        For details on the output, visit
+        http://code.google.com/apis/maps/documentation/geocoding/#ReverseGeocoding
+
+        """
+        params = {
+            'latlng':   "%f,%f" % (lat, lng),
+            'sensor':   sensor,
+            'bounds':   bounds,
+            'region':   region,
+            'language': language,
+        }
+
+        if self is not None:
+            return GeocoderResult(self.get_data(params=params))
+        else:
+            return GeocoderResult(Geocoder.get_data(params=params))
+
     def set_proxy(self, proxy):
         """
         Makes every HTTP request to Google geocoding server use the supplied proxy
@@ -118,83 +198,6 @@ class Geocoder(object):
         request.params['client'] = str(self.client_id)
         request.params['signature'] = encoded_signature
 
-    @omnimethod
-    def geocode(self, address, sensor='false', bounds='', region='', language=''):
-        """
-        Given a string address, return a dictionary of information about
-        that location, including its latitude and longitude.
-
-        :param address: Address of location to be geocoded.
-        :type address: string
-        :param sensor: ``'true'`` if the address is coming from, say, a GPS device.
-        :type sensor: string
-        :param bounds: The bounding box of the viewport within which to bias geocode results more prominently.
-        :type bounds: string
-        :param region: The region code, specified as a ccTLD ("top-level domain") two-character value for biasing
-        :type region: string
-        :param language: The language in which to return results.
-        :type language: string
-        :returns: `geocoder return value`_ dictionary
-        :rtype: dict
-        :raises GeocoderError: if there is something wrong with the query.
-
-        For details on the input parameters, visit
-        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingRequests
-
-        For details on the output, visit
-        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingResponses
-
-        """
-
-        params = {
-            'address':  address,
-            'sensor':   sensor,
-            'bounds':   bounds,
-            'region':   region,
-            'language': language,
-        }
-
-        if self is not None:
-            return GeocoderResult(self.get_data(params=params))
-        else:
-            return GeocoderResult(Geocoder.get_data(params=params))
-
-    @omnimethod
-    def reverse_geocode(self, lat, lng, sensor='false', bounds='', region='', language=''):
-        """
-        Converts a (latitude, longitude) pair to an address.
-
-        :param lat: latitude
-        :type lat: float
-        :param lng: longitude
-        :type lng: float
-        :return: `Reverse geocoder return value`_ dictionary giving closest
-            address(es) to `(lat, lng)`
-        :rtype: dict
-        :raises GeocoderError: If the coordinates could not be reverse geocoded.
-
-        Keyword arguments and return value are identical to those of :meth:`geocode()`.
-
-        For details on the input parameters, visit
-        http://code.google.com/apis/maps/documentation/geocoding/#GeocodingRequests
-
-        For details on the output, visit
-        http://code.google.com/apis/maps/documentation/geocoding/#ReverseGeocoding
-
-        """
-        params = {
-            'latlng':   "%f,%f" % (lat, lng),
-            'sensor':   sensor,
-            'bounds':   bounds,
-            'region':   region,
-            'language': language,
-        }
-
-        if self is not None:
-            return GeocoderResult(self.get_data(params=params))
-        else:
-            return GeocoderResult(Geocoder.get_data(params=params))
-
 if __name__ == "__main__":
     import sys
     from optparse import OptionParser
